
<table id="GeoLocationHexTable" aria-describedby="GeoLocationHexTable" cellspacing="0">
    <thead>
        <tr>
        <th style="border-right: 1px solid #000;border-bottom: 1px solid #000;">Offset</th>
        <th style="width: 100px; border-right: 1px solid #000;border-bottom: 1px solid #000;">Hex</th>
        <th style="border-bottom: 1px solid #000;">Ascii</th>
    </tr>
    </thead>
    <tbody>
    <tr>
    <td style="white-space:nowrap; border-right: 1px solid #000;">{{dump.str_offset}}</td>
    <td style="border-right: 1px solid #000; white-space:nowrap;">{{dump.str_hex}}</td>
    <td style="white-space:nowrap;">{{dump.str_ascii}}</td>
    </tr>
    </tbody>
</table>
