__authors__ = [
    [
        "Alexis Brignoni",
        "https://abrignoni.com",
        "@AlexisBrignoni",
        "https://github.com/abrignoni",
    ],
    [
        "Yogesh Khatri",
        "https://swiftforensics.com",
        "@SwiftForensics",
        "https://github.com/ydkhatri",
    ],
]

__contributors__ = [
    ["Agam Dua", "https://loopback.dev", "@loopbackdev", "https://github.com/agamdua"],
    [
        "Sarah Edwards",
        "https://www.mac4n6.com",
        "@iamevltwin",
        "https://github.com/mac4n6",
    ],
    ["Heather Mahalik", "https://smarterforensics.com", "@HeatherMahalik", ""],
    ["Jessica Hyde", "https://twitter.com/B1N2H3X", "@B1N2H3X", ""],
    [
        "Phill Moore",
        "https://thinkdfir.com",
        "@phillmoore",
        "https://github.com/randomaccess3",
    ],
    ["Mattia Epifani", "https://blog.digital-forensics.it", "@mattiaep", ""],
    [
        "Mike Williamson",
        "https://forensicmike1.com",
        "@forensicmike1",
        "https://github.com/forensicmike",
    ],
    ["Geraldine Blay", "https://gforce4n6.blogspot.com", "@i_am_the_gia", ""],
    ["Christopher Vance", "https://blog.d204n6.com", "@cScottVance", ""],
    ["Brooke Gottlieb", "", "@xbrookego", ""],
    ["Jack Farley", "http://farleyforensics.com", "@JackFarley248", ""],
    ["Shafik Punja", "", "@qubytelogic", ""],
    [
        "Cheeky4N6Monkey",
        "https://cheeky4n6monkey.blogspot.com",
        "@Cheeky4n6Monkey",
        "https://github.com/cheeky4n6monkey",
    ],
    ["Edward Greybeard", "", "", "https://github.com/edward-greybeard"],
    ["Douglas Kein", "", "@DouglasKein", ""],
    ["Claudia Meda", "", "@KlodiaMaida", "https://github.com/KlodiaMaida"],
    ["Silvia Spallarossa", "", "@SilviaSpallaro1", "https://github.com/spatimbs"],
    ["Francesca Maestri", "", "@franc3sca_m", "https://github.com/francyM"],
    [
        "Christopher Vance",
        "https://blog.d204n6.com/",
        "@cScottVance",
        "https://github.com/cScottVance",
    ],
    [
        "Jesse Spangenberger",
        "https://cyberfenixtech.blogspot.com/",
        "@AzuleOnyx",
        "https://github.com/flamusdiu",
    ],
    [
        "Jon Baumann",
        "https://ciofecaforensics.com/",
        "@CiofecaForensic",
        "https://github.com/threeplanetssoftware",
    ],
    ["Scott Koenig", "", "@Scott_Kjr", ""],
    [
        "Kevin Pagano",
        "https://stark4n6.com/",
        "@KevinPagano3",
        "https://github.com/stark4n6",
    ],
    ["Ed Michael", "", "@EdXlg123", "https://github.com/edmichael"],
    ["Anna-Mariya Mateyna", "", "@any333_snickers", "https://github.com/any333"],
    ["Tommy Harris", "", "@tobraha", "https://github.com/tobraha"],
]
