                <div class="card bg-white mb-3" style="max-width: 500px; margin:auto">
                    <div class="row no-gutters">
                        <div class="col-md-4">
                            <img src="_static/logo.jpg" class="card-img" alt="DFIR">
                        </div>
                        <div class="col-md-8">
                        <div class="card-body">
                            <h5 class="card-title">Thank you for using xLEAPP</h5>
                            <p class="card-text">
                                Support open source and report any bugs!
                            </p>
                            <!--Github-->
                            <a class="btn-floating btn-git" type="button" role="button" href="https://github.com/abrignoni/xleapp" target="_blank"><i class="fab fa-github"></i> Project Home </a>
                            <p class="card-text fadeIn"><small class="text-muted">xLEAPP Team</small></p>
                        </div>
                    </div>
                </div>
